import { HttpRequest as IHttpRequest, HttpResponse as IHttpResponse } from "@aws-sdk/types";
/**
 * Parses well-formed HTTP request strings into HTTP request objects.
 *
 * This function was written to facilitate working with wire logs rather than to
 * be part of the critical path of an HTTP stack; it was not designed with
 * performance in mind.
 *
 * @see https://tools.ietf.org/html/rfc7230#section-3
 */
export declare function parseRequest(serialized: string): IHttpRequest;
/**
 * Parses well-formed HTTP response strings into HTTP response objects.
 *
 * This function was written to facilitate working with wire logs rather than to
 * be part of the critical path of an HTTP stack; it was not designed with
 * performance in mind.
 *
 * @see https://tools.ietf.org/html/rfc7230#section-3
 */
export declare function parseResponse(serialized: string): IHttpResponse;
/**
 * Formats HTTP requests into well-formed message strings.
 *
 * This function was written to aid in the creation of wire logs rather than to
 * be part of the critical path of an HTTP stack; it was not designed with
 * performance in mind.
 *
 * @see https://tools.ietf.org/html/rfc7230#section-3
 */
export declare function serializeRequest(request: IHttpRequest): string;
/**
 * Formats HTTP responses into well-formed message strings.
 *
 * This function was written to aid in the creation of wire logs rather than to
 * be part of the critical path of an HTTP stack; it was not designed with
 * performance in mind.
 *
 * @see https://tools.ietf.org/html/rfc7230#section-3
 */
export declare function serializeResponse(response: IHttpResponse): string;
